@@ -8,7 +8,7 @@
 #endif
 
 module Text.RE.Internal.PreludeMacros
-  ( RegexType(..)
+  ( RegexType
   , WithCaptures(..)
   , MacroDescriptor(..)
   , RegexSource(..)
@@ -30,11 +30,12 @@ import           Data.Maybe
 import qualified Data.Text                    as T
 import           Data.Time
 import           Prelude.Compat
-import           Text.RE.Options
-import           Text.RE.Parsers
+import           Text.RE.Types.REOptions
+import           Text.RE.TestBench.Parsers
 import           Text.RE.TestBench
 
 
+-- | generate the standard prelude Macros used to parse REs
 preludeMacros :: (Monad m,Functor m)
               => (String->m r)
               -> RegexType
@@ -42,30 +43,29 @@ preludeMacros :: (Monad m,Functor m)
               -> m (Macros r)
 preludeMacros prs rty wc = mkMacros prs rty wc $ preludeMacroEnv rty
 
+-- | format the standard prelude macros in a markdown table
 preludeMacroTable :: RegexType -> String
 preludeMacroTable rty = formatMacroTable rty $ preludeMacroEnv rty
 
+-- | generate a textual summary of the prelude macros
 preludeMacroSummary :: RegexType -> PreludeMacro -> String
 preludeMacroSummary rty =
   formatMacroSummary rty (preludeMacroEnv rty) . prelude_macro_id
 
+-- | generate a plain text table giving the RE for each macro with all
+-- macros expanded (to NF)
 preludeMacroSources :: RegexType -> String
 preludeMacroSources rty =
   formatMacroSources rty ExclCaptures $ preludeMacroEnv rty
 
+-- | generate plain text giving theexpanded RE for a single macro
 preludeMacroSource :: RegexType -> PreludeMacro -> String
 preludeMacroSource rty =
   formatMacroSource rty ExclCaptures (preludeMacroEnv rty) . prelude_macro_id
 
+-- | generate the `MacroEnv` for the standard prelude macros
 preludeMacroEnv :: RegexType -> MacroEnv
-preludeMacroEnv TDFA = prelude_macro_env_tdfa
-preludeMacroEnv PCRE = prelude_macro_env_pcre
-
-prelude_macro_env_pcre :: MacroEnv
-prelude_macro_env_pcre = fix $ prelude_macro_env PCRE
-
-prelude_macro_env_tdfa :: MacroEnv
-prelude_macro_env_tdfa = fix $ prelude_macro_env TDFA
+preludeMacroEnv rty = fix $ prelude_macro_env rty
 
 prelude_macro_env :: RegexType -> MacroEnv -> MacroEnv
 prelude_macro_env rty env = HML.fromList $ catMaybes
@@ -73,6 +73,7 @@ prelude_macro_env rty env = HML.fromList $ catMaybes
       | pm<-[minBound..maxBound]
       ]
 
+-- | generate the `MacroDescriptor` for a given `PreludeMacro`
 preludeMacroDescriptor :: RegexType
                        -> MacroEnv
                        -> PreludeMacro
@@ -192,8 +193,8 @@ natural_hex_macro rty env pm = Just $ run_tests rty parseHex samples env pm
     samples =
       [ (,) "0"         0x0
       , (,) "12345678"  0x12345678
-      , (,) "90abcdef"  0x90abcdef
-      , (,) "90ABCDEF"  0x90abcdef
+      , (,) "0abcdef"   0xabcdef
+      , (,) "0ABCDEF"   0xabcdef
       , (,) "00"        0x0
       , (,) "010"       0x10
       ]
@@ -273,17 +274,18 @@ string_macro :: RegexType
              -> MacroEnv
              -> PreludeMacro
              -> Maybe MacroDescriptor
-string_macro     PCRE _  _   = Nothing
-string_macro rty@TDFA env pm =
-  Just $ run_tests rty (fmap T.unpack . parseString) samples env pm
-    MacroDescriptor
-      { _md_source          = "\"(?:[^\"\\]+|\\\\[\\\"])*\""
-      , _md_samples         = map fst samples
-      , _md_counter_samples = counter_samples
-      , _md_test_results    = []
-      , _md_parser          = Just "parseString"
-      , _md_description     = "a double-quote string, with simple \\ escapes for \\s and \"s"
-      }
+string_macro rty env pm
+  | isPCRE rty = Nothing
+  | otherwise  =
+    Just $ run_tests rty (fmap T.unpack . parseString) samples env pm
+      MacroDescriptor
+        { _md_source          = "\"(?:[^\"\\]+|\\\\[\\\"])*\""
+        , _md_samples         = map fst samples
+        , _md_counter_samples = counter_samples
+        , _md_test_results    = []
+        , _md_parser          = Just "parseString"
+        , _md_description     = "a double-quote string, with simple \\ escapes for \\s and \"s"
+        }
   where
     samples :: [(String,String)]
     samples =
@@ -795,9 +797,9 @@ syslog_severity_macro rty env pm =
         , "ALERT"
         ]
 
-    re = case rty of
-      PCRE -> re_pcre
-      TDFA -> re_tdfa
+    re = if isPCRE rty
+      then re_pcre
+      else re_tdfa
 
     re_tdfa = bracketedRegexSource $
           intercalate "|" $
